==> hs-shakespeare-text-0.10.3.tbz: lib/ghc-7.0.4/cabal/shakespeare-text-0.10.3/register.sh <==
#!/bin/sh
echo 'name: shakespeare-text
version: 0.10.3
id: shakespeare-text-0.10.3-7bbd2a765237c6f7dcd5a9e41e941030

license: BSD3
copyright:
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/templates
package-url:
description: interpolation with quasi-quotation: stick haskell variables into haskell strings
             .
             Note there is no dependency on haskell-src-extras. If you don'\''t mind that dependency, you may want to look at using these packages: Interpolation, interpolatedstring-perl6, interpolatedstring-qq.
             .
             This package has 1 other general feature that those others may not (but would be easy to duplicate): instead of using quasi-quoting you can also use an external file. It also has url/embeding interpolation, with \@ and \^, which are used in Yesod.
             .
             This package also uses blaze-builder for efficiently constructing strings (I am not sure what the other packages use). This might be of interest to you for large templates or performance sensitive code, or otherwise having a nice interface to blaze-builder
             .
             Shakespeare is a template family for type-safe, efficient templates with simple variable interpolation . Shakespeare templates can be used inline with a quasi-quoter or in an external file. Shakespeare interpolates variables according to the type being inserted.
             In this case, the variable type needs a ToText instance.
             .
             Please see http://docs.yesodweb.com/book/templates for a more thorough description and examples of the shakespeare family of template languages.
category: Web, Yesod
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules: Text.Shakespeare.Text
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/shakespeare-text-0.10.3
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/shakespeare-text-0.10.3
              /usr/local/lib
hs-libraries: HSshakespeare-text-0.10.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         shakespeare-0.10.2-e1af66eb3dbfbd12af79fe4e1960964c
         template-haskell-2.5.0.0-adafdd03731a91bbb4c278042a2e11df
         text-0.11.1.5-b4f492f688b9a01c2b4d3a9904e832bc
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/shakespeare-text-0.10.3/html/shakespeare-text.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/shakespeare-text-0.10.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-shakespeare-text-1.0.0.2_1.tbz: lib/ghc-7.4.1/cabal/shakespeare-text-1.0.0.2/register.sh <==
#!/bin/sh
echo 'name: shakespeare-text
version: 1.0.0.2
id: shakespeare-text-1.0.0.2-7048883009e71c476b964924d0987cc5

license: MIT
copyright:
maintainer: Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
package-url:
synopsis: Interpolation with quasi-quotation: put variables strings
description: interpolation with quasi-quotation: stick haskell variables into haskell strings
             .
             Note there is no dependency on haskell-src-extras. If you don'\''t mind that dependency, you may want to look at using these packages: Interpolation, interpolatedstring-perl6, interpolatedstring-qq.
             .
             This package has 1 other general feature that those others may not (but would be easy to duplicate): instead of using quasi-quoting you can also use an external file. It also has url/embeding interpolation, with \@ and \^, which are used in Yesod.
             .
             This package also uses blaze-builder for efficiently constructing strings (I am not sure what the other packages use). This might be of interest to you for large templates or performance sensitive code, or otherwise having a nice interface to blaze-builder
             .
             Shakespeare is a template family for type-safe, efficient templates with simple variable interpolation . Shakespeare templates can be used inline with a quasi-quoter or in an external file. Shakespeare interpolates variables according to the type being inserted.
             In this case, the variable type needs a ToText instance.
             .
             Please see http://www.yesodweb.com/book/shakespearean-templates for a more thorough description and examples of the shakespeare family of template languages.
category: Web, Yesod
author: Greg Weber <greg@gregweber.info>
exposed: True
exposed-modules: Text.Shakespeare.Text
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/shakespeare-text-1.0.0.2
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/shakespeare-text-1.0.0.2
              /usr/local/lib
hs-libraries: HSshakespeare-text-1.0.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         shakespeare-1.0.0.2-f57f59b24ccbb0972754a6c42a155d0f
         template-haskell-2.7.0.0-5f2f37ca11e7c427e50f296b61fe13e2
         text-0.11.2.0-e612aa676a8fce1c637c16c9eb2bc9e2
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/shakespeare-text-1.0.0.2/html/shakespeare-text.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/shakespeare-text-1.0.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
